==========
Change Log
==========

`0.1.3`_ (2018-09-04)
---------------------
* trustlines-contracts-deploy has been released to PyPI

`0.1.2`_ (2018-08-21)
---------------------
* trustlines-contracts has also been released to PyPI

`0.1.1`_ (2018-08-20)
---------------------
* trustlines-contracts-bin has been released to PyPI


.. _0.1.1: https://github.com/trustlines-network/contracts/compare/0.1.0...0.1.1
.. _0.1.2: https://github.com/trustlines-network/contracts/compare/0.1.1...0.1.2
.. _0.1.3: https://github.com/trustlines-network/contracts/compare/0.1.2...0.1.3
